"""
This is the functions for data file format conversion
"""
def ebf_to_fits(fn, col_list_out=None):
    """
    This is used to  convert the ebf file to fits format.
    :param fn: The file name of the ebf file including ".ebf", specially the file generated by Galaxia
    :param list_out: The columns for output. Default is None, then all the columns with fmts in float or INT are saved
    :return: The saved data will be returned
    """
    import ebf
    from astropy.table import Table
    data = ebf.read(fn)
    fn_out = fn[:-4]+".fits"
    if col_list_out is None:
        col_list_out = ['px', 'py', 'pz', 'vx', 'vy', 'vz', 'feh',
                        'alpha', 'smass', 'age', 'rad', 'mag0', 'mag1', 'mag2',
                        'popid', 'satid', 'fieldid', 'partid', 'teff',
                        'grav', 'mact', 'mtip', 'sdss_u', 'sdss_g',
                        'sdss_r', 'sdss_i', 'sdss_z', 'exbv_schlegel',
                        'exbv_solar', 'exbv_schlegel_inf', 'glon', 'glat']
    out_table = Table()
    for snm in col_list_out:
        out_table[snm] = data[snm]
    out_table.write(fn_out, overwrite=True)
    return out_table

